import 'slickgrid/slick.compositeeditor.js';
import { CompositeEditorOpenDetailOption, ContainerService, Editor, EditorValidationResult, ExternalResource, GridOption, SlickEventHandler, SlickGrid, SlickDataView } from '@slickgrid-universal/common';
export declare class SlickCompositeEditorComponent implements ExternalResource {
    private _bindEventService;
    private _eventHandler;
    private _modalElm;
    private _options;
    private _lastActiveRowNumber;
    private _locales;
    private _formValues;
    private _editors;
    private _editorContainers;
    private _modalBodyTopValidationElm;
    private _modalSaveButtonElm;
    private grid;
    private gridService;
    private gridStateService;
    private translaterService?;
    get eventHandler(): SlickEventHandler;
    get dataView(): SlickDataView;
    get dataViewLength(): number;
    get formValues(): any;
    get editors(): {
        [columnId: string]: Editor;
    };
    set editors(editors: {
        [columnId: string]: Editor;
    });
    get gridOptions(): GridOption;
    constructor();
    init(grid: SlickGrid, containerService: ContainerService): void;
    /** Dispose of the Component & unsubscribe all events */
    dispose(): void;
    /** Dispose of the Component without unsubscribing any events */
    disposeComponent(): void;
    /**
     * Dynamically change value of an input from the Composite Editor form
     * @param {String} columnId - column id
     * @param {*} newValue - the new value
     */
    changeFormInputValue(columnId: string, newValue: any): void;
    /**
     * Dynamically change an Editor option of the Composite Editor form
     * For example, a use case could be to dynamically change the "minDate" of another Date Editor in the Composite Editor form.
     * @param {String} columnId - column id
     * @param {*} newValue - the new value
     */
    changeFormEditorOption(columnId: string, optionName: string, newOptionValue: any): void;
    /**
     * Disable (or enable) an input of the Composite Editor form
     * @param columnId
     * @param isDisabled
     */
    disableFormInput(columnId: string, isDisabled?: boolean): void;
    openDetails(options: CompositeEditorOpenDetailOption): SlickCompositeEditorComponent | null;
    /** Apply Mass Update Changes from a the form changes */
    applySaveMassUpdateChanges(formValues: any): void;
    applySaveMassSelectionChanges(formValues: any, selection: {
        gridRowIndexes: number[];
        dataContextIds: Array<number | string>;
    }): void;
    cancelEditing(): Promise<void>;
    handleSaveClicked(): void;
    handleMassSaving(modalType: 'mass-update' | 'mass-selection', executeCallback: () => void): Promise<void>;
    showValidationSummaryText(isShowing: boolean, errorMsg?: string): void;
    validateCurrentEditor(): void;
    /**
     * Auto-Calculate how many columns to display in the view layout (1, 2, or 3).
     * We'll display a 1 column layount for 8 or less Editors, 2 columns layout for less than 15 Editors or 3 columns when more than 15 Editors
     * @param {number} editorCount - how many Editors do we have in total
     * @returns {number} count - calculated column count (1, 2 or 3)
     */
    private autoCalculateLayoutColumnCount;
    private executeOnError;
    /**
     * Get the column label, the label might have an optional "columnGroup" (or "columnGroupKey" which need to be translated)
     * @param {object} columnDef - column definition
     * @returns {string} label - column label
     */
    private getColumnLabel;
    private handleBodyClicked;
    private handleKeyDown;
    private focusOnFirstColumnCellWithEditor;
    private findNextAvailableEditorColumnIndex;
    private getActiveCellEditor;
    private getLabelText;
    private handleOnAddNewRow;
    /** Anytime an input of the Composite Editor form changes, we'll add/remove a "modified" CSS className for styling purposes */
    private handleOnCompositeEditorChange;
    /** Check wether the grid has the Row Selection enabled */
    private hasRowSelectionEnabled;
    private parseText;
    validateCompositeEditors(targetElm?: HTMLElement): EditorValidationResult;
}
